BarcodeResults class

Store and count every potential result Once a barcode was identified minimalResultCount times, it is considered as a valid result

Constructors

BarcodeResults({bool singleShot = false, int minimalResultCount = 2})

Properties

gotResult → bool
Consider that we have a barcode result once enough identic results are found
no setter
hashCode → int
The hash code for this object.
no setterinherited
minimalResultCount ↔ int
Number of identic scanned value to get before consider getting result
getter/setter pair
mostFrequentBarcode → String
returns the barcode with the most results
no setter
resultCount → int
return the actual barcode results count
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
singleShot ↔ bool
Set to true if you want to get the first scanned value with no concordance check
getter/setter pair

Methods

add(String barcode) → void
adds a new barcode result
clear() → void
clears all barcode results
countOf(String barcode) → int
returns the count of a barcode
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited