CamCodeScanner class

Camera barcode scanner widget Asks for camera access permission Shows camera images stream Captures pictures every 'refreshDelayMillis' Ask your favorite javascript library to identify a barcode in the current picture

Inheritance

Constructors

CamCodeScanner({bool showDebugFrames = false, required Function onBarcodeResult, required double width, required double height, int refreshDelayMillis = 1000, CamCodeScannerController? controller, Color backgroundColor = Colors.black54, bool showScannerLine = true, int minimalResultCount = 2})
Camera barcode scanner widget Params:

Properties

backgroundColor → Color
The color of the background mask
final
controller → CamCodeScannerController?
controller to control the camera from outside
final
hashCode → int
The hash code for this object.
no setterinherited
height → double
height dimension
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
minimalResultCount → int
Number of identic scanned value to get before consider getting result
final
onBarcodeResult → Function
call back to trigger on barcode result
final
refreshDelayMillis → int
delay between to picture analysis
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showDebugFrames → bool
shows the current analysing picture
final
showScannerLine → bool
shows the current analysing picture
final
width → double
width dimension
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _CamCodeScannerState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited