CamcodeWeb class

A web implementation of the Camcode plugin.

Constructors

CamcodeWeb()

Properties

completer ↔ Completer<String>
used to transmit result to the Widget via MethodChannel
getter/setter pair
counter ↔ int
getter/setter pair
frameSize ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
imageElement ↔ ImageElement
ImageElement used to display taken pictures
getter/setter pair
maxAttempt ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

fetchDevices() → Future<List<String>>
wait for the list of devices to be completed
fetchResult() → Future<String>
wait for the result to be completed
handleMethodCall(MethodCall call) → Future
handle channel calls
initialize(double width, double height, int refreshDelayMillis, int minimalResultCount) → int
Initialize the scanner :
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onBarcodeResult(String _barcode) → Future<void>
Method called on barcode result to finish the process and send result
releaseResources() → void
Release resources to avoid leaks
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

registerWith(Registrar registrar) → void
Registering method